@@ -1,4 +1,4 @@
-'V1.12.04'
+'V1.12.05'
 '''Change Log
 bbs in show will accept a numpy array
 show image torch tensor bug
@@ -210,7 +210,10 @@ def show(img=None, ax=None, title=None, sz=None, bbs=None, confs=None,
             pass
         bbs = df2bbs(df) # assumes df has 'x,y,X,Y' columns
     if isinstance(texts, pd.core.series.Series): texts = texts.tolist()
-    if texts:
+    if texts is not None:
+        if hasattr(texts, 'shape'):
+            if isinstance(texts, torch.Tensor): texts = texts.cpu().detach().numpy()
+            texts = texts.tolist()
         texts = list(texts)
         if texts is 'ixs': texts = [i for i in range(len(bbs))]
         if callable(texts): texts = [texts(bb) for bb in bbs]
@@ -219,14 +222,10 @@ def show(img=None, ax=None, title=None, sz=None, bbs=None, confs=None,
         texts = ['*' if len(t.strip())==0 else t for t in texts]
         [puttext(ax, text.replace('$','\$'), tuple(bbs[ix][:2]), size=text_sz) for ix,text in enumerate(texts)]
     if confs:
-        # from colour import Color
-        # colors = list(Color("red").range_to(Color("green"), 5))
-        # colors = [[int(i*255) for i in c.get_rgb()] for c in colors]
         colors = [[255, 0, 0], [223, 111, 0], [191, 191, 0], [79, 159, 0], [0, 128, 0]]
         bb_colors = [colors[ int(cnf*5)-1 ] for cnf in confs]
     if isinstance(bbs, np.ndarray): bbs = bbs.astype(np.uint16).tolist()
-    if bbs:
-        'rect-th'
+    if bbs is not None:
         if 'th' in kwargs:
             th = kwargs.get('th')
             kwargs.pop('th')
@@ -234,6 +233,10 @@ def show(img=None, ax=None, title=None, sz=None, bbs=None, confs=None,
             if w<800: th=2
             elif w<1600: th=3
             else: th=4
+        if hasattr(bbs, 'shape'):
+            if isinstance(bbs, torch.Tensor): bbs = bbs.cpu().detach().numpy()
+            bbs = bbs.astype(np.uint32).tolist()
+
         bb_colors = [[randint(255) for _ in range(3)] for _ in range(len(bbs))] if bb_colors is 'random' else bb_colors
         bb_colors = [None]*len(bbs) if bb_colors is None else bb_colors
         img = C(img) if len(img.shape) == 2 else img
